"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright Aristech GmbH"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetProjectsRequest(google.protobuf.message.Message):
    """Methods and datatypes for (vector) content management"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetProjectsRequest = GetProjectsRequest

@typing.final
class Project(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the project"""
    name: builtins.str
    """Name of the project"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name"]) -> None: ...

global___Project = Project

@typing.final
class AddProjectRequest(google.protobuf.message.Message):
    """adds a project to the underlying database(s)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EMBEDDING_MODEL_FIELD_NUMBER: builtins.int
    FALLBACK_MESSAGES_FIELD_NUMBER: builtins.int
    DEFAULT_THRESHOLD_FIELD_NUMBER: builtins.int
    TEAM_ID_FIELD_NUMBER: builtins.int
    DEBUG_MODE_FIELD_NUMBER: builtins.int
    EXCLUDE_OUTPUT_FROM_SEARCH_FIELD_NUMBER: builtins.int
    HISTORY_FIELD_NUMBER: builtins.int
    CONFIG_SLUG_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Project name"""
    description: builtins.str
    """description of the project"""
    default_threshold: builtins.float
    """default_threshold for search requests"""
    team_id: builtins.str
    debug_mode: builtins.bool
    exclude_output_from_search: builtins.bool
    config_slug: builtins.str
    slug: builtins.str
    @property
    def embedding_model(self) -> global___EmbeddingModel:
        """model to use for vectorembeddings"""

    @property
    def fallback_messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FallbackMessage]:
        """Fallback Messages"""

    @property
    def history(self) -> global___History: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        embedding_model: global___EmbeddingModel | None = ...,
        fallback_messages: collections.abc.Iterable[global___FallbackMessage] | None = ...,
        default_threshold: builtins.float = ...,
        team_id: builtins.str = ...,
        debug_mode: builtins.bool = ...,
        exclude_output_from_search: builtins.bool = ...,
        history: global___History | None = ...,
        config_slug: builtins.str = ...,
        slug: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["embedding_model", b"embedding_model", "history", b"history"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config_slug", b"config_slug", "debug_mode", b"debug_mode", "default_threshold", b"default_threshold", "description", b"description", "embedding_model", b"embedding_model", "exclude_output_from_search", b"exclude_output_from_search", "fallback_messages", b"fallback_messages", "history", b"history", "name", b"name", "slug", b"slug", "team_id", b"team_id"]) -> None: ...

global___AddProjectRequest = AddProjectRequest

@typing.final
class FallbackMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FallbackMessage._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CHAT: FallbackMessage._Type.ValueType  # 0
        EMAIL: FallbackMessage._Type.ValueType  # 1
        VOICE: FallbackMessage._Type.ValueType  # 2

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    CHAT: FallbackMessage.Type.ValueType  # 0
    EMAIL: FallbackMessage.Type.ValueType  # 1
    VOICE: FallbackMessage.Type.ValueType  # 2

    MESSAGE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    message: builtins.str
    type: global___FallbackMessage.Type.ValueType
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        type: global___FallbackMessage.Type.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["message", b"message", "type", b"type"]) -> None: ...

global___FallbackMessage = FallbackMessage

@typing.final
class History(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATOR_ID_FIELD_NUMBER: builtins.int
    CHANGED_BY_FIELD_NUMBER: builtins.int
    CREATION_DATE_FIELD_NUMBER: builtins.int
    LAST_EDIT_DATE_FIELD_NUMBER: builtins.int
    creator_id: builtins.str
    """object id with the creator id"""
    changed_by: builtins.str
    """id of the user who made the last change"""
    creation_date: builtins.str
    """Date of creation"""
    last_edit_date: builtins.str
    """date of last edit"""
    def __init__(
        self,
        *,
        creator_id: builtins.str = ...,
        changed_by: builtins.str = ...,
        creation_date: builtins.str = ...,
        last_edit_date: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["changed_by", b"changed_by", "creation_date", b"creation_date", "creator_id", b"creator_id", "last_edit_date", b"last_edit_date"]) -> None: ...

global___History = History

@typing.final
class AddProjectResponse(google.protobuf.message.Message):
    """response for adding a project. returns the project_id of the created project"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """id of the created project"""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___AddProjectResponse = AddProjectResponse

@typing.final
class RemoveProjectRequest(google.protobuf.message.Message):
    """removes the project and all of its content"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project to be removed"""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___RemoveProjectRequest = RemoveProjectRequest

@typing.final
class RemoveProjectResponse(google.protobuf.message.Message):
    """response for remove project request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RemoveProjectResponse = RemoveProjectResponse

@typing.final
class GetEmbeddingModelsRequest(google.protobuf.message.Message):
    """request to get all available embedding models from the server"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetEmbeddingModelsRequest = GetEmbeddingModelsRequest

@typing.final
class EmbeddingModel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DIMENSIONS_FIELD_NUMBER: builtins.int
    BASE_LIBRARY_FIELD_NUMBER: builtins.int
    LOCALE_FIELD_NUMBER: builtins.int
    name: builtins.str
    dimensions: builtins.int
    base_library: builtins.str
    @property
    def locale(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        dimensions: builtins.int = ...,
        base_library: builtins.str = ...,
        locale: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["base_library", b"base_library", "dimensions", b"dimensions", "locale", b"locale", "name", b"name"]) -> None: ...

global___EmbeddingModel = EmbeddingModel

@typing.final
class UpdateProjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EMBEDDING_MODEL_FIELD_NUMBER: builtins.int
    FALLBACK_MESSAGES_FIELD_NUMBER: builtins.int
    DEFAULT_THRESHOLD_FIELD_NUMBER: builtins.int
    DEBUG_MODE_FIELD_NUMBER: builtins.int
    EXCLUDE_OUTPUT_FROM_SEARCH_FIELD_NUMBER: builtins.int
    HISTORY_FIELD_NUMBER: builtins.int
    CONFIG_SLUG_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """the id of the project to be updated, if no id is set, a new project is created"""
    name: builtins.str
    """Project name"""
    description: builtins.str
    """description of the project"""
    default_threshold: builtins.float
    """default_threshold for search requests"""
    debug_mode: builtins.bool
    exclude_output_from_search: builtins.bool
    config_slug: builtins.str
    slug: builtins.str
    @property
    def embedding_model(self) -> global___EmbeddingModel:
        """model to use for vectorembeddings"""

    @property
    def fallback_messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FallbackMessage]:
        """Fallback Messages"""

    @property
    def history(self) -> global___History: ...
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        embedding_model: global___EmbeddingModel | None = ...,
        fallback_messages: collections.abc.Iterable[global___FallbackMessage] | None = ...,
        default_threshold: builtins.float = ...,
        debug_mode: builtins.bool = ...,
        exclude_output_from_search: builtins.bool = ...,
        history: global___History | None = ...,
        config_slug: builtins.str = ...,
        slug: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["embedding_model", b"embedding_model", "history", b"history"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config_slug", b"config_slug", "debug_mode", b"debug_mode", "default_threshold", b"default_threshold", "description", b"description", "embedding_model", b"embedding_model", "exclude_output_from_search", b"exclude_output_from_search", "fallback_messages", b"fallback_messages", "history", b"history", "name", b"name", "project_id", b"project_id", "slug", b"slug"]) -> None: ...

global___UpdateProjectRequest = UpdateProjectRequest

@typing.final
class UpdateProjectResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateProjectResponse = UpdateProjectResponse



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import intents_pb2 as intents__pb2
from . import nlp_server_pb2 as nlp__server__pb2
from . import projects_pb2 as projects__pb2

GRPC_GENERATED_VERSION = '1.68.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in nlp_server_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class NLPServerStub(object):
    """Interface exported by the server.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetFunctions = channel.unary_stream(
                '/aristech.nlp.NLPServer/GetFunctions',
                request_serializer=nlp__server__pb2.FunctionRequest.SerializeToString,
                response_deserializer=nlp__server__pb2.Function.FromString,
                _registered_method=True)
        self.RunFunctions = channel.unary_unary(
                '/aristech.nlp.NLPServer/RunFunctions',
                request_serializer=nlp__server__pb2.RunFunctionsRequest.SerializeToString,
                response_deserializer=nlp__server__pb2.RunFunctionsResponse.FromString,
                _registered_method=True)
        self.UpdateContent = channel.unary_unary(
                '/aristech.nlp.NLPServer/UpdateContent',
                request_serializer=intents__pb2.UpdateContentRequest.SerializeToString,
                response_deserializer=intents__pb2.UpdateContentResponse.FromString,
                _registered_method=True)
        self.RemoveContent = channel.unary_unary(
                '/aristech.nlp.NLPServer/RemoveContent',
                request_serializer=intents__pb2.RemoveContentRequest.SerializeToString,
                response_deserializer=intents__pb2.RemoveContentResponse.FromString,
                _registered_method=True)
        self.GetContent = channel.unary_stream(
                '/aristech.nlp.NLPServer/GetContent',
                request_serializer=intents__pb2.GetContentRequest.SerializeToString,
                response_deserializer=intents__pb2.GetContentResponse.FromString,
                _registered_method=True)
        self.AddProject = channel.unary_unary(
                '/aristech.nlp.NLPServer/AddProject',
                request_serializer=projects__pb2.AddProjectRequest.SerializeToString,
                response_deserializer=projects__pb2.AddProjectResponse.FromString,
                _registered_method=True)
        self.RemoveProject = channel.unary_unary(
                '/aristech.nlp.NLPServer/RemoveProject',
                request_serializer=projects__pb2.RemoveProjectRequest.SerializeToString,
                response_deserializer=projects__pb2.RemoveProjectResponse.FromString,
                _registered_method=True)
        self.UpdateProject = channel.unary_unary(
                '/aristech.nlp.NLPServer/UpdateProject',
                request_serializer=projects__pb2.UpdateProjectRequest.SerializeToString,
                response_deserializer=projects__pb2.UpdateProjectResponse.FromString,
                _registered_method=True)
        self.GetProjects = channel.unary_stream(
                '/aristech.nlp.NLPServer/GetProjects',
                request_serializer=projects__pb2.GetProjectsRequest.SerializeToString,
                response_deserializer=projects__pb2.Project.FromString,
                _registered_method=True)
        self.GetIntents = channel.unary_stream(
                '/aristech.nlp.NLPServer/GetIntents',
                request_serializer=intents__pb2.GetIntentsRequest.SerializeToString,
                response_deserializer=intents__pb2.GetIntentsResponse.FromString,
                _registered_method=True)
        self.GetScoreLimits = channel.unary_unary(
                '/aristech.nlp.NLPServer/GetScoreLimits',
                request_serializer=intents__pb2.GetScoreLimitsRequest.SerializeToString,
                response_deserializer=intents__pb2.GetScoreLimitsResponse.FromString,
                _registered_method=True)
        self.GetEmbeddingModels = channel.unary_stream(
                '/aristech.nlp.NLPServer/GetEmbeddingModels',
                request_serializer=projects__pb2.GetEmbeddingModelsRequest.SerializeToString,
                response_deserializer=projects__pb2.EmbeddingModel.FromString,
                _registered_method=True)


class NLPServerServicer(object):
    """Interface exported by the server.
    """

    def GetFunctions(self, request, context):
        """A simple RPC.
        returns all available processing Models.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunFunctions(self, request, context):
        """A server-to-client streaming method
        Returns the processed text
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateContent(self, request, context):
        """Method to add content to a vector database.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveContent(self, request, context):
        """Method to remove content from a vector database.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContent(self, request, context):
        """Method to get content from a vector database.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddProject(self, request, context):
        """Method to initialize a project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveProject(self, request, context):
        """Method to remove Project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProject(self, request, context):
        """update the settings of a project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProjects(self, request, context):
        """Method to get projects from a vector database
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntents(self, request, context):
        """Method to get intents from a project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetScoreLimits(self, request, context):
        """Method to get score limits for a project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEmbeddingModels(self, request, context):
        """get the available embedding models to be used for similarity search
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NLPServerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetFunctions': grpc.unary_stream_rpc_method_handler(
                    servicer.GetFunctions,
                    request_deserializer=nlp__server__pb2.FunctionRequest.FromString,
                    response_serializer=nlp__server__pb2.Function.SerializeToString,
            ),
            'RunFunctions': grpc.unary_unary_rpc_method_handler(
                    servicer.RunFunctions,
                    request_deserializer=nlp__server__pb2.RunFunctionsRequest.FromString,
                    response_serializer=nlp__server__pb2.RunFunctionsResponse.SerializeToString,
            ),
            'UpdateContent': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateContent,
                    request_deserializer=intents__pb2.UpdateContentRequest.FromString,
                    response_serializer=intents__pb2.UpdateContentResponse.SerializeToString,
            ),
            'RemoveContent': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveContent,
                    request_deserializer=intents__pb2.RemoveContentRequest.FromString,
                    response_serializer=intents__pb2.RemoveContentResponse.SerializeToString,
            ),
            'GetContent': grpc.unary_stream_rpc_method_handler(
                    servicer.GetContent,
                    request_deserializer=intents__pb2.GetContentRequest.FromString,
                    response_serializer=intents__pb2.GetContentResponse.SerializeToString,
            ),
            'AddProject': grpc.unary_unary_rpc_method_handler(
                    servicer.AddProject,
                    request_deserializer=projects__pb2.AddProjectRequest.FromString,
                    response_serializer=projects__pb2.AddProjectResponse.SerializeToString,
            ),
            'RemoveProject': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveProject,
                    request_deserializer=projects__pb2.RemoveProjectRequest.FromString,
                    response_serializer=projects__pb2.RemoveProjectResponse.SerializeToString,
            ),
            'UpdateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProject,
                    request_deserializer=projects__pb2.UpdateProjectRequest.FromString,
                    response_serializer=projects__pb2.UpdateProjectResponse.SerializeToString,
            ),
            'GetProjects': grpc.unary_stream_rpc_method_handler(
                    servicer.GetProjects,
                    request_deserializer=projects__pb2.GetProjectsRequest.FromString,
                    response_serializer=projects__pb2.Project.SerializeToString,
            ),
            'GetIntents': grpc.unary_stream_rpc_method_handler(
                    servicer.GetIntents,
                    request_deserializer=intents__pb2.GetIntentsRequest.FromString,
                    response_serializer=intents__pb2.GetIntentsResponse.SerializeToString,
            ),
            'GetScoreLimits': grpc.unary_unary_rpc_method_handler(
                    servicer.GetScoreLimits,
                    request_deserializer=intents__pb2.GetScoreLimitsRequest.FromString,
                    response_serializer=intents__pb2.GetScoreLimitsResponse.SerializeToString,
            ),
            'GetEmbeddingModels': grpc.unary_stream_rpc_method_handler(
                    servicer.GetEmbeddingModels,
                    request_deserializer=projects__pb2.GetEmbeddingModelsRequest.FromString,
                    response_serializer=projects__pb2.EmbeddingModel.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aristech.nlp.NLPServer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('aristech.nlp.NLPServer', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class NLPServer(object):
    """Interface exported by the server.
    """

    @staticmethod
    def GetFunctions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/aristech.nlp.NLPServer/GetFunctions',
            nlp__server__pb2.FunctionRequest.SerializeToString,
            nlp__server__pb2.Function.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RunFunctions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/aristech.nlp.NLPServer/RunFunctions',
            nlp__server__pb2.RunFunctionsRequest.SerializeToString,
            nlp__server__pb2.RunFunctionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateContent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/aristech.nlp.NLPServer/UpdateContent',
            intents__pb2.UpdateContentRequest.SerializeToString,
            intents__pb2.UpdateContentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoveContent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/aristech.nlp.NLPServer/RemoveContent',
            intents__pb2.RemoveContentRequest.SerializeToString,
            intents__pb2.RemoveContentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetContent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/aristech.nlp.NLPServer/GetContent',
            intents__pb2.GetContentRequest.SerializeToString,
            intents__pb2.GetContentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/aristech.nlp.NLPServer/AddProject',
            projects__pb2.AddProjectRequest.SerializeToString,
            projects__pb2.AddProjectResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoveProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/aristech.nlp.NLPServer/RemoveProject',
            projects__pb2.RemoveProjectRequest.SerializeToString,
            projects__pb2.RemoveProjectResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/aristech.nlp.NLPServer/UpdateProject',
            projects__pb2.UpdateProjectRequest.SerializeToString,
            projects__pb2.UpdateProjectResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/aristech.nlp.NLPServer/GetProjects',
            projects__pb2.GetProjectsRequest.SerializeToString,
            projects__pb2.Project.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetIntents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/aristech.nlp.NLPServer/GetIntents',
            intents__pb2.GetIntentsRequest.SerializeToString,
            intents__pb2.GetIntentsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetScoreLimits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/aristech.nlp.NLPServer/GetScoreLimits',
            intents__pb2.GetScoreLimitsRequest.SerializeToString,
            intents__pb2.GetScoreLimitsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEmbeddingModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/aristech.nlp.NLPServer/GetEmbeddingModels',
            projects__pb2.GetEmbeddingModelsRequest.SerializeToString,
            projects__pb2.EmbeddingModel.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright Aristech GmbH"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Intent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _InputType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _InputTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Intent._InputType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CHAT: Intent._InputType.ValueType  # 0
        MAIL: Intent._InputType.ValueType  # 1
        VOICE: Intent._InputType.ValueType  # 2

    class InputType(_InputType, metaclass=_InputTypeEnumTypeWrapper): ...
    CHAT: Intent.InputType.ValueType  # 0
    MAIL: Intent.InputType.ValueType  # 1
    VOICE: Intent.InputType.ValueType  # 2

    ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    LOCALE_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    OUTPUT_CHAT_FIELD_NUMBER: builtins.int
    OUTPUT_VOICE_FIELD_NUMBER: builtins.int
    OUTPUT_EMAIL_FIELD_NUMBER: builtins.int
    RELATED_TO_FIELD_NUMBER: builtins.int
    PUBLISHED_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EXCLUDE_OUTPUT_FROM_SEARCH_FIELD_NUMBER: builtins.int
    KEYWORDS_FIELD_NUMBER: builtins.int
    CREATOR_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the intent"""
    project_id: builtins.str
    """The project ID of the intent"""
    locale: builtins.str
    """The default locale for the intent's inputs and outputs"""
    topic: builtins.str
    """Topic of the intent"""
    published: builtins.bool
    """If the intent is a draft"""
    type: global___Intent.InputType.ValueType
    """Type of the intents inputs"""
    exclude_output_from_search: builtins.bool
    creator_id: builtins.str
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IntentInput]:
        """Inputs for the intent"""

    @property
    def output_chat(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Possible chat outputs for the intent"""

    @property
    def output_voice(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Possible voice outputs for the intent
        This is usually a JSON string with key value pairs e.g. {"extension": "1234", "text": "I will redirect you to the support team"}
        """

    @property
    def output_email(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Possible email outputs for the intent"""

    @property
    def related_to(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Relation]:
        """relation to other intents"""

    @property
    def keywords(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Keyword]:
        """List of keywords to force finding this intent"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        project_id: builtins.str = ...,
        locale: builtins.str = ...,
        topic: builtins.str = ...,
        inputs: collections.abc.Iterable[global___IntentInput] | None = ...,
        output_chat: collections.abc.Iterable[builtins.str] | None = ...,
        output_voice: collections.abc.Iterable[builtins.str] | None = ...,
        output_email: collections.abc.Iterable[builtins.str] | None = ...,
        related_to: collections.abc.Iterable[global___Relation] | None = ...,
        published: builtins.bool = ...,
        type: global___Intent.InputType.ValueType = ...,
        exclude_output_from_search: builtins.bool = ...,
        keywords: collections.abc.Iterable[global___Keyword] | None = ...,
        creator_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["creator_id", b"creator_id", "exclude_output_from_search", b"exclude_output_from_search", "id", b"id", "inputs", b"inputs", "keywords", b"keywords", "locale", b"locale", "output_chat", b"output_chat", "output_email", b"output_email", "output_voice", b"output_voice", "project_id", b"project_id", "published", b"published", "related_to", b"related_to", "topic", b"topic", "type", b"type"]) -> None: ...

global___Intent = Intent

@typing.final
class IntentInput(google.protobuf.message.Message):
    """a type defining an input and its mapping to a uuid. if the uuid is set, the input gets edited
    to the new input, if no id is set or the uuid does not exist, a new input is added to the 
    intent.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UUID_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    uuid: builtins.str
    input: builtins.str
    def __init__(
        self,
        *,
        uuid: builtins.str = ...,
        input: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["input", b"input", "uuid", b"uuid"]) -> None: ...

global___IntentInput = IntentInput

@typing.final
class Relation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARENTS_FIELD_NUMBER: builtins.int
    CHILDREN_FIELD_NUMBER: builtins.int
    PEERS_FIELD_NUMBER: builtins.int
    @property
    def parents(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """list of ids of  parent intents"""

    @property
    def children(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """list of ids of  child intents"""

    @property
    def peers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """list of ids of same level intents"""

    def __init__(
        self,
        *,
        parents: collections.abc.Iterable[builtins.str] | None = ...,
        children: collections.abc.Iterable[builtins.str] | None = ...,
        peers: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["children", b"children", "parents", b"parents", "peers", b"peers"]) -> None: ...

global___Relation = Relation

@typing.final
class Keyword(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYWORD_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    keyword: builtins.str
    """a keyword for an intent"""
    priority: builtins.int
    """the priority for the keyword"""
    def __init__(
        self,
        *,
        keyword: builtins.str = ...,
        priority: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["keyword", b"keyword", "priority", b"priority"]) -> None: ...

global___Keyword = Keyword

@typing.final
class UpdateContentRequest(google.protobuf.message.Message):
    """Adds or updates content to the vector database
    if id of the intent is not set, a new intent is created for the project
    if an id is set: first check if that id already exists and update it
    if the id doesn't exist: create the intent with the given id.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTENTS_FIELD_NUMBER: builtins.int
    @property
    def intents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Intent]: ...
    def __init__(
        self,
        *,
        intents: collections.abc.Iterable[global___Intent] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["intents", b"intents"]) -> None: ...

global___UpdateContentRequest = UpdateContentRequest

@typing.final
class UpdateContentResponse(google.protobuf.message.Message):
    """Response for add content"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTENT_IDS_FIELD_NUMBER: builtins.int
    @property
    def intent_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Status of the update"""

    def __init__(
        self,
        *,
        intent_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["intent_ids", b"intent_ids"]) -> None: ...

global___UpdateContentResponse = UpdateContentResponse

@typing.final
class RemoveContentRequest(google.protobuf.message.Message):
    """Removes content from the vector database"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """"""
    @property
    def id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """ID of the Document to be removed"""

    def __init__(
        self,
        *,
        id: collections.abc.Iterable[builtins.str] | None = ...,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "project_id", b"project_id"]) -> None: ...

global___RemoveContentRequest = RemoveContentRequest

@typing.final
class RemoveContentResponse(google.protobuf.message.Message):
    """Response for remove content"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RemoveContentResponse = RemoveContentResponse

@typing.final
class GetContentRequest(google.protobuf.message.Message):
    """Request for content"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    NUM_RESULTS_FIELD_NUMBER: builtins.int
    THRESHOLD_FIELD_NUMBER: builtins.int
    FILTERS_FIELD_NUMBER: builtins.int
    CHAT_ID_FIELD_NUMBER: builtins.int
    prompt: builtins.str
    """Prompt for the content to be retrieved"""
    project_id: builtins.str
    """Meta data for the content to be retrieved"""
    num_results: builtins.int
    """The number of results to be returned"""
    threshold: builtins.float
    """The threshold for the results to be returned"""
    chat_id: builtins.str
    """Chat id for context"""
    @property
    def filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContentFilter]:
        """Content Filters"""

    def __init__(
        self,
        *,
        prompt: builtins.str = ...,
        project_id: builtins.str = ...,
        num_results: builtins.int = ...,
        threshold: builtins.float = ...,
        filters: collections.abc.Iterable[global___ContentFilter] | None = ...,
        chat_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["chat_id", b"chat_id", "filters", b"filters", "num_results", b"num_results", "project_id", b"project_id", "prompt", b"prompt", "threshold", b"threshold"]) -> None: ...

global___GetContentRequest = GetContentRequest

@typing.final
class GetContentResponse(google.protobuf.message.Message):
    """Response for content"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    CHAT_ID_FIELD_NUMBER: builtins.int
    chat_id: builtins.str
    """The Chat ID that was sent to the server with the get content request"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContentResponseItem]:
        """List of intents"""

    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___ContentResponseItem] | None = ...,
        chat_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["chat_id", b"chat_id", "items", b"items"]) -> None: ...

global___GetContentResponse = GetContentResponse

@typing.final
class ContentFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    field: builtins.str
    """The field to be filtered"""
    value: builtins.str
    """The value to be filtered"""
    operator: builtins.str
    """Operator"""
    @property
    def label(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The label to be used for filtering"""

    def __init__(
        self,
        *,
        field: builtins.str = ...,
        value: builtins.str = ...,
        operator: builtins.str = ...,
        label: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["field", b"field", "label", b"label", "operator", b"operator", "value", b"value"]) -> None: ...

global___ContentFilter = ContentFilter

@typing.final
class ContentResponseItem(google.protobuf.message.Message):
    """Response item for content"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    INTENT_FIELD_NUMBER: builtins.int
    FALLBACK_MESSAGE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Id of the intent's input that represents this match"""
    score: builtins.float
    """Score of the content"""
    fallback_message: builtins.str
    """fallbackmessage, gets set, when no intent was found in the search"""
    @property
    def intent(self) -> global___Intent:
        """The actual intent"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        score: builtins.float = ...,
        intent: global___Intent | None = ...,
        fallback_message: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["intent", b"intent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["fallback_message", b"fallback_message", "id", b"id", "intent", b"intent", "score", b"score"]) -> None: ...

global___ContentResponseItem = ContentResponseItem

@typing.final
class GetIntentsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___GetIntentsRequest = GetIntentsRequest

@typing.final
class GetIntentsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTENT_FIELD_NUMBER: builtins.int
    @property
    def intent(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Intent]: ...
    def __init__(
        self,
        *,
        intent: collections.abc.Iterable[global___Intent] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["intent", b"intent"]) -> None: ...

global___GetIntentsResponse = GetIntentsResponse

@typing.final
class GetScoreLimitsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    TEST_SENTENCES_UPPER_LIMIT_FIELD_NUMBER: builtins.int
    TEST_SENTENCES_LOWER_LIMIT_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project to get the score Limits from"""
    @property
    def test_sentences_upper_limit(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of sentences to test for the upper limit"""

    @property
    def test_sentences_lower_limit(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of sentences to test for the lower limit"""

    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        test_sentences_upper_limit: collections.abc.Iterable[builtins.str] | None = ...,
        test_sentences_lower_limit: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id", "test_sentences_lower_limit", b"test_sentences_lower_limit", "test_sentences_upper_limit", b"test_sentences_upper_limit"]) -> None: ...

global___GetScoreLimitsRequest = GetScoreLimitsRequest

@typing.final
class GetScoreLimitsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_THRESHOLD_FIELD_NUMBER: builtins.int
    MAX_THRESHOLD_FIELD_NUMBER: builtins.int
    min_threshold: builtins.float
    """The minimum threshold determined by random sentences"""
    max_threshold: builtins.float
    """The max threshold determined by using original input sentences for the
    intents
    """
    def __init__(
        self,
        *,
        min_threshold: builtins.float = ...,
        max_threshold: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["max_threshold", b"max_threshold", "min_threshold", b"min_threshold"]) -> None: ...

global___GetScoreLimitsResponse = GetScoreLimitsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: intents.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'intents.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rintents.proto\x12\x0c\x61ristech.nlp\"\xad\x03\n\x06Intent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\r\n\x05topic\x18\x04 \x01(\t\x12)\n\x06inputs\x18\x05 \x03(\x0b\x32\x19.aristech.nlp.IntentInput\x12\x13\n\x0boutput_chat\x18\x06 \x03(\t\x12\x14\n\x0coutput_voice\x18\x07 \x03(\t\x12\x14\n\x0coutput_email\x18\x08 \x03(\t\x12*\n\nrelated_to\x18\t \x03(\x0b\x32\x16.aristech.nlp.Relation\x12\x11\n\tpublished\x18\n \x01(\x08\x12,\n\x04type\x18\x0b \x01(\x0e\x32\x1e.aristech.nlp.Intent.InputType\x12\"\n\x1a\x65xclude_output_from_search\x18\x0c \x01(\x08\x12\'\n\x08keywords\x18\r \x03(\x0b\x32\x15.aristech.nlp.Keyword\x12\x12\n\ncreator_id\x18\x0e \x01(\t\"*\n\tInputType\x12\x08\n\x04\x43HAT\x10\x00\x12\x08\n\x04MAIL\x10\x01\x12\t\n\x05VOICE\x10\x02\"*\n\x0bIntentInput\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\t\"<\n\x08Relation\x12\x0f\n\x07parents\x18\x01 \x03(\t\x12\x10\n\x08\x63hildren\x18\x02 \x03(\t\x12\r\n\x05peers\x18\x03 \x03(\t\",\n\x07Keyword\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x10\n\x08priority\x18\x02 \x01(\x05\"=\n\x14UpdateContentRequest\x12%\n\x07intents\x18\x01 \x03(\x0b\x32\x14.aristech.nlp.Intent\"+\n\x15UpdateContentResponse\x12\x12\n\nintent_ids\x18\x01 \x03(\t\"6\n\x14RemoveContentRequest\x12\n\n\x02id\x18\x01 \x03(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\"\x17\n\x15RemoveContentResponse\"\x9e\x01\n\x11GetContentRequest\x12\x0e\n\x06prompt\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x13\n\x0bnum_results\x18\x03 \x01(\x05\x12\x11\n\tthreshold\x18\x04 \x01(\x02\x12,\n\x07\x66ilters\x18\x05 \x03(\x0b\x32\x1b.aristech.nlp.ContentFilter\x12\x0f\n\x07\x63hat_id\x18\x07 \x01(\t\"W\n\x12GetContentResponse\x12\x30\n\x05items\x18\x01 \x03(\x0b\x32!.aristech.nlp.ContentResponseItem\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\t\"N\n\rContentFilter\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x10\n\x08operator\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x03(\t\"p\n\x13\x43ontentResponseItem\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\x12$\n\x06intent\x18\x03 \x01(\x0b\x32\x14.aristech.nlp.Intent\x12\x18\n\x10\x66\x61llback_message\x18\x04 \x01(\t\"\'\n\x11GetIntentsRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\":\n\x12GetIntentsResponse\x12$\n\x06intent\x18\x01 \x03(\x0b\x32\x14.aristech.nlp.Intent\"s\n\x15GetScoreLimitsRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\"\n\x1atest_sentences_upper_limit\x18\x02 \x03(\t\x12\"\n\x1atest_sentences_lower_limit\x18\x03 \x03(\t\"F\n\x16GetScoreLimitsResponse\x12\x15\n\rmin_threshold\x18\x01 \x01(\x02\x12\x15\n\rmax_threshold\x18\x02 \x01(\x02\x42\x08P\x01\xa2\x02\x03\x41TSb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'intents_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001\242\002\003ATS'
  _globals['_INTENT']._serialized_start=32
  _globals['_INTENT']._serialized_end=461
  _globals['_INTENT_INPUTTYPE']._serialized_start=419
  _globals['_INTENT_INPUTTYPE']._serialized_end=461
  _globals['_INTENTINPUT']._serialized_start=463
  _globals['_INTENTINPUT']._serialized_end=505
  _globals['_RELATION']._serialized_start=507
  _globals['_RELATION']._serialized_end=567
  _globals['_KEYWORD']._serialized_start=569
  _globals['_KEYWORD']._serialized_end=613
  _globals['_UPDATECONTENTREQUEST']._serialized_start=615
  _globals['_UPDATECONTENTREQUEST']._serialized_end=676
  _globals['_UPDATECONTENTRESPONSE']._serialized_start=678
  _globals['_UPDATECONTENTRESPONSE']._serialized_end=721
  _globals['_REMOVECONTENTREQUEST']._serialized_start=723
  _globals['_REMOVECONTENTREQUEST']._serialized_end=777
  _globals['_REMOVECONTENTRESPONSE']._serialized_start=779
  _globals['_REMOVECONTENTRESPONSE']._serialized_end=802
  _globals['_GETCONTENTREQUEST']._serialized_start=805
  _globals['_GETCONTENTREQUEST']._serialized_end=963
  _globals['_GETCONTENTRESPONSE']._serialized_start=965
  _globals['_GETCONTENTRESPONSE']._serialized_end=1052
  _globals['_CONTENTFILTER']._serialized_start=1054
  _globals['_CONTENTFILTER']._serialized_end=1132
  _globals['_CONTENTRESPONSEITEM']._serialized_start=1134
  _globals['_CONTENTRESPONSEITEM']._serialized_end=1246
  _globals['_GETINTENTSREQUEST']._serialized_start=1248
  _globals['_GETINTENTSREQUEST']._serialized_end=1287
  _globals['_GETINTENTSRESPONSE']._serialized_start=1289
  _globals['_GETINTENTSRESPONSE']._serialized_end=1347
  _globals['_GETSCORELIMITSREQUEST']._serialized_start=1349
  _globals['_GETSCORELIMITSREQUEST']._serialized_end=1464
  _globals['_GETSCORELIMITSRESPONSE']._serialized_start=1466
  _globals['_GETSCORELIMITSRESPONSE']._serialized_end=1536
# @@protoc_insertion_point(module_scope)



from .client import NlpClient
from .proto.nlp_server_pb2_grpc import *
from .proto.nlp_server_pb2 import *
from .proto.projects_pb2_grpc import *
from .proto.projects_pb2 import *
from .proto.intents_pb2_grpc import *
from .proto.intents_pb2 import *

__all__ = [
  "NlpClient",
  "FunctionRequest",
  "Function",
  "GetProjectsRequest",
  "Project",
  "GetIntentsRequest",
  "Intent",
  "RunFunctionsRequest",
  "RunFunctionsResponse",
  "GetScoreLimitsRequest",
  "GetContentRequest",
  "GetContentResponse",
  "UpdateContentRequest",
  "UpdateContentResponse",
  "RemoveContentRequest",
  "RemoveContentResponse",
  "ContentMetaData",
  "ContentData",
  "DescriptionMapping",
  "Output",
]


"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright Aristech GmbH"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class FunctionRequest(google.protobuf.message.Message):
    """Request for list of functions that server provides"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___FunctionRequest = FunctionRequest

@typing.final
class Function(google.protobuf.message.Message):
    """A function is a specific operation or information that can be performed on
    incoming text. I.E. Classification, recasing etc.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ARGUMENTS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """An unique ID for the function used (i.e. useful when using different
    versions of a functions)
    """
    name: builtins.str
    """An self-explaining name of the function"""
    description: builtins.str
    """A description of the function."""
    @property
    def arguments(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of arguments for the function"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        arguments: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["arguments", b"arguments", "description", b"description", "id", b"id", "name", b"name"]) -> None: ...

global___Function = Function

@typing.final
class RunFunctionsRequest(google.protobuf.message.Message):
    """Process raw text input."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTIONS_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    ARGUMENTS_FIELD_NUMBER: builtins.int
    input: builtins.str
    """The input to be processed"""
    @property
    def functions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Function]:
        """Function to be requested"""

    @property
    def arguments(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Arguments, if necessary. I.E. switchting between raw output and debug
        output.
        """

    def __init__(
        self,
        *,
        functions: collections.abc.Iterable[global___Function] | None = ...,
        input: builtins.str = ...,
        arguments: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["arguments", b"arguments", "functions", b"functions", "input", b"input"]) -> None: ...

global___RunFunctionsRequest = RunFunctionsRequest

@typing.final
class RunFunctionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUT_FIELD_NUMBER: builtins.int
    output: builtins.str
    """Processed text"""
    def __init__(
        self,
        *,
        output: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["output", b"output"]) -> None: ...

global___RunFunctionsResponse = RunFunctionsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nlp_server.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'nlp_server.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import projects_pb2 as projects__pb2
from . import intents_pb2 as intents__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10nlp_server.proto\x12\x0c\x61ristech.nlp\x1a\x0eprojects.proto\x1a\rintents.proto\"\x11\n\x0f\x46unctionRequest\"L\n\x08\x46unction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\targuments\x18\x04 \x03(\t\"b\n\x13RunFunctionsRequest\x12)\n\tfunctions\x18\x01 \x03(\x0b\x32\x16.aristech.nlp.Function\x12\r\n\x05input\x18\x02 \x01(\t\x12\x11\n\targuments\x18\x03 \x03(\t\"&\n\x14RunFunctionsResponse\x12\x0e\n\x06output\x18\x01 \x01(\t2\xa8\x08\n\tNLPServer\x12I\n\x0cGetFunctions\x12\x1d.aristech.nlp.FunctionRequest\x1a\x16.aristech.nlp.Function\"\x00\x30\x01\x12W\n\x0cRunFunctions\x12!.aristech.nlp.RunFunctionsRequest\x1a\".aristech.nlp.RunFunctionsResponse\"\x00\x12Z\n\rUpdateContent\x12\".aristech.nlp.UpdateContentRequest\x1a#.aristech.nlp.UpdateContentResponse\"\x00\x12Z\n\rRemoveContent\x12\".aristech.nlp.RemoveContentRequest\x1a#.aristech.nlp.RemoveContentResponse\"\x00\x12S\n\nGetContent\x12\x1f.aristech.nlp.GetContentRequest\x1a .aristech.nlp.GetContentResponse\"\x00\x30\x01\x12Q\n\nAddProject\x12\x1f.aristech.nlp.AddProjectRequest\x1a .aristech.nlp.AddProjectResponse\"\x00\x12Z\n\rRemoveProject\x12\".aristech.nlp.RemoveProjectRequest\x1a#.aristech.nlp.RemoveProjectResponse\"\x00\x12Z\n\rUpdateProject\x12\".aristech.nlp.UpdateProjectRequest\x1a#.aristech.nlp.UpdateProjectResponse\"\x00\x12J\n\x0bGetProjects\x12 .aristech.nlp.GetProjectsRequest\x1a\x15.aristech.nlp.Project\"\x00\x30\x01\x12S\n\nGetIntents\x12\x1f.aristech.nlp.GetIntentsRequest\x1a .aristech.nlp.GetIntentsResponse\"\x00\x30\x01\x12]\n\x0eGetScoreLimits\x12#.aristech.nlp.GetScoreLimitsRequest\x1a$.aristech.nlp.GetScoreLimitsResponse\"\x00\x12_\n\x12GetEmbeddingModels\x12\'.aristech.nlp.GetEmbeddingModelsRequest\x1a\x1c.aristech.nlp.EmbeddingModel\"\x00\x30\x01\x42\x08P\x01\xa2\x02\x03\x41TSb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nlp_server_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001\242\002\003ATS'
  _globals['_FUNCTIONREQUEST']._serialized_start=65
  _globals['_FUNCTIONREQUEST']._serialized_end=82
  _globals['_FUNCTION']._serialized_start=84
  _globals['_FUNCTION']._serialized_end=160
  _globals['_RUNFUNCTIONSREQUEST']._serialized_start=162
  _globals['_RUNFUNCTIONSREQUEST']._serialized_end=260
  _globals['_RUNFUNCTIONSRESPONSE']._serialized_start=262
  _globals['_RUNFUNCTIONSRESPONSE']._serialized_end=300
  _globals['_NLPSERVER']._serialized_start=303
  _globals['_NLPSERVER']._serialized_end=1367
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: projects.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'projects.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eprojects.proto\x12\x0c\x61ristech.nlp\"\x14\n\x12GetProjectsRequest\"#\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd6\x02\n\x11\x41\x64\x64ProjectRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x35\n\x0f\x65mbedding_model\x18\x03 \x01(\x0b\x32\x1c.aristech.nlp.EmbeddingModel\x12\x38\n\x11\x66\x61llback_messages\x18\x04 \x03(\x0b\x32\x1d.aristech.nlp.FallbackMessage\x12\x19\n\x11\x64\x65\x66\x61ult_threshold\x18\x05 \x01(\x02\x12\x0f\n\x07team_id\x18\x06 \x01(\t\x12\x12\n\ndebug_mode\x18\x07 \x01(\x08\x12\"\n\x1a\x65xclude_output_from_search\x18\x08 \x01(\x08\x12&\n\x07history\x18\t \x01(\x0b\x32\x15.aristech.nlp.History\x12\x13\n\x0b\x63onfig_slug\x18\n \x01(\t\x12\x0c\n\x04slug\x18\x0b \x01(\t\"|\n\x0f\x46\x61llbackMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x30\n\x04type\x18\x02 \x01(\x0e\x32\".aristech.nlp.FallbackMessage.Type\"&\n\x04Type\x12\x08\n\x04\x43HAT\x10\x00\x12\t\n\x05\x45MAIL\x10\x01\x12\t\n\x05VOICE\x10\x02\"`\n\x07History\x12\x12\n\ncreator_id\x18\x01 \x01(\t\x12\x12\n\nchanged_by\x18\x02 \x01(\t\x12\x15\n\rcreation_date\x18\x03 \x01(\t\x12\x16\n\x0elast_edit_date\x18\x04 \x01(\t\"(\n\x12\x41\x64\x64ProjectResponse\x12\x12\n\nproject_id\x18\x01 \x01(\t\"*\n\x14RemoveProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\x17\n\x15RemoveProjectResponse\"\x1b\n\x19GetEmbeddingModelsRequest\"X\n\x0e\x45mbeddingModel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ndimensions\x18\x02 \x01(\x05\x12\x14\n\x0c\x62\x61se_library\x18\x03 \x01(\t\x12\x0e\n\x06locale\x18\x04 \x03(\t\"\xdc\x02\n\x14UpdateProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x35\n\x0f\x65mbedding_model\x18\x04 \x01(\x0b\x32\x1c.aristech.nlp.EmbeddingModel\x12\x38\n\x11\x66\x61llback_messages\x18\x05 \x03(\x0b\x32\x1d.aristech.nlp.FallbackMessage\x12\x19\n\x11\x64\x65\x66\x61ult_threshold\x18\x06 \x01(\x02\x12\x12\n\ndebug_mode\x18\x07 \x01(\x08\x12\"\n\x1a\x65xclude_output_from_search\x18\x08 \x01(\x08\x12&\n\x07history\x18\t \x01(\x0b\x32\x15.aristech.nlp.History\x12\x13\n\x0b\x63onfig_slug\x18\n \x01(\t\x12\x0c\n\x04slug\x18\x0b \x01(\t\"\x17\n\x15UpdateProjectResponseB\x08P\x01\xa2\x02\x03\x41TSb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'projects_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001\242\002\003ATS'
  _globals['_GETPROJECTSREQUEST']._serialized_start=32
  _globals['_GETPROJECTSREQUEST']._serialized_end=52
  _globals['_PROJECT']._serialized_start=54
  _globals['_PROJECT']._serialized_end=89
  _globals['_ADDPROJECTREQUEST']._serialized_start=92
  _globals['_ADDPROJECTREQUEST']._serialized_end=434
  _globals['_FALLBACKMESSAGE']._serialized_start=436
  _globals['_FALLBACKMESSAGE']._serialized_end=560
  _globals['_FALLBACKMESSAGE_TYPE']._serialized_start=522
  _globals['_FALLBACKMESSAGE_TYPE']._serialized_end=560
  _globals['_HISTORY']._serialized_start=562
  _globals['_HISTORY']._serialized_end=658
  _globals['_ADDPROJECTRESPONSE']._serialized_start=660
  _globals['_ADDPROJECTRESPONSE']._serialized_end=700
  _globals['_REMOVEPROJECTREQUEST']._serialized_start=702
  _globals['_REMOVEPROJECTREQUEST']._serialized_end=744
  _globals['_REMOVEPROJECTRESPONSE']._serialized_start=746
  _globals['_REMOVEPROJECTRESPONSE']._serialized_end=769
  _globals['_GETEMBEDDINGMODELSREQUEST']._serialized_start=771
  _globals['_GETEMBEDDINGMODELSREQUEST']._serialized_end=798
  _globals['_EMBEDDINGMODEL']._serialized_start=800
  _globals['_EMBEDDINGMODEL']._serialized_end=888
  _globals['_UPDATEPROJECTREQUEST']._serialized_start=891
  _globals['_UPDATEPROJECTREQUEST']._serialized_end=1239
  _globals['_UPDATEPROJECTRESPONSE']._serialized_start=1241
  _globals['_UPDATEPROJECTRESPONSE']._serialized_end=1264
# @@protoc_insertion_point(module_scope)



import grpc
import re

from typing import Iterable

from .proto.nlp_server_pb2_grpc import *
from .proto.nlp_server_pb2 import *
from .proto.projects_pb2_grpc import *
from .proto.projects_pb2 import *
from .proto.intents_pb2_grpc import *
from .proto.intents_pb2 import *

class NlpClient:
    host: str
    ssl: bool
    rootCert: bytes
    auth_token: str
    auth_secret: str
    channel: grpc.Channel

    def __init__(self, host: str, ssl=None, root_cert=b"", auth_token="", auth_secret=""):
      """
      Initializes the client with the given connection parameters.

      Args:
        host (str): The host to connect to. Can include the port, e.g. "localhost:8524".
        ssl (bool): Whether to use SSL. If not explicitly set, the client will try to guess based on the remaining parameters.
        root_cert (bytes): The root certificate to use for SSL (e.g. when connecting to a server that uses a self-signed certificate).
        auth_token (str): The auth token to use for authentication.
        auth_secret (str): The auth secret to use for authentication.
      """
      # When ssl or rootCert are not explicitly set, we check if the host includes the port 9424 or 9423.
      # If host does not include the port, we assume ssl is True and the port is 9424 therefore.
      defaultSsl = (ssl is None and len(root_cert) == 0) or (ssl is True or len(root_cert) != 0)
      (h, p) = self._get_host_port(host, defaultSsl)
      self.host = h + ":" + p
      self.ssl = ssl is True or len(root_cert) != 0 or p == "8524"
      self.rootCert = root_cert
      self.auth_token = auth_token
      self.auth_secret = auth_secret
      if self.ssl or self.rootCert:
        self.channel = self._create_secure_channel()
      else:
        self.channel = grpc.insecure_channel(self.host)
    
    def _get_host_port(self, host, defaultSsl):
      portRe = r"^(?P<host>[^:]+):(?P<port>[0-9]+)$"
      matches = re.search(portRe, host)
      defaultPort = defaultSsl and "8524" or "8523"
      return (host, defaultPort) if matches is None else (matches.group("host"), matches.group("port"))
    
    def _metadata_callback(self, context, callback):
      callback([('token', self.auth_token), ('secret', self.auth_secret)], None)

    def _create_secure_channel(self):
        if len(self.rootCert) != 0:
          cert_creds = grpc.ssl_channel_credentials(root_certificates=self.rootCert)
        else:
          cert_creds = grpc.ssl_channel_credentials()
        auth_creds = grpc.metadata_call_credentials(self._metadata_callback)
        combined_creds = grpc.composite_channel_credentials(cert_creds, auth_creds)
        channel = grpc.secure_channel(target=self.host, credentials=combined_creds)
        return channel

    def list_functions(self, request=FunctionRequest()) -> Iterable[Function]:
        """
        Lists the available functions.

        Args:
          request (FunctionRequest): The request to send. Defaults to an empty request.
        
        Returns:
          Iterable[Function]: The functions available.
        """
        stub = NLPServerStub(self.channel)
        return stub.GetFunctions(request)
  
    def list_projects(self, request=GetProjectsRequest()) -> Iterable[Project]:
        """
        Lists the available projects.

        Args:
          request (GetProjectsRequest): The request to send. Defaults to an empty request.
        
        Returns:
          Iterable[Project]: The projects available.
        """
        stub = NLPServerStub(self.channel)
        return stub.GetProjects(request)
    
    def list_intents(self, request: GetIntentsRequest) -> Iterable[Intent]:
        """
        Lists the available intents for a given project.

        Args:
          request (GetIntentsRequest): The request to send.
        
        Returns:
          Iterable[GetIntentsResponse]: The intents available.
        """
        stub = NLPServerStub(self.channel)
        return stub.GetIntents(request)
    
    def list_embedding_models(self, request=GetEmbeddingModelsRequest) -> Iterable[EmbeddingModel]:
      """
       Lists the available embedding models.

      Args:
        request (GetEmbeddingModelsRequest): The request to send.

      Returns:
        Iterable[EmbeddingModel]: The embedding models available. 
      """
      stub = NLPServerStub(self.channel)
      return stub.RemoveContent(request)
  
    def run_functions(self, request: RunFunctionsRequest) -> RunFunctionsResponse:
        """
        Processes a raw text.

        Args:
          request (RunFunctionsRequest): The request to send.
        
        Returns:
          Iterable[RunFunctionsResponse]: The responses with the processed text.
        """
        stub = NLPServerStub(self.channel)
        return stub.RunFunctions(request)
    
    def score_limits(self, request: GetScoreLimitsRequest) -> GetScoreLimitsResponse:
        """
        Gets the score limits for a given project.

        Args:
          request (GetScoreLimitsRequest): The request to send.
        
        Returns:
          GetScoreLimitsResponse: The score limits.
        """
        stub = NLPServerStub(self.channel)
        return stub.GetScoreLimits(request)
    
    def get_content(self, request: GetContentRequest) -> Iterable[GetContentResponse]:
        """
        Gets the content for a given project.

        Args:
          request (GetContentRequest): The request to send.
        
        Returns:
          Iterable[GetContentResponse]: The content available.
        """
        stub = NLPServerStub(self.channel)
        return stub.GetContent(request)
    
    def update_content(self, request: UpdateContentRequest) -> UpdateContentResponse:
        """
        Updates the content that matches the given request.

        Args:
          request (UpdateContentRequest): The request to send.
        
        Returns:
          UpdateContentResponse: The response.
        """
        stub = NLPServerStub(self.channel)
        return stub.UpdateContent(request)
    
    def remove_content(self, request: RemoveContentRequest) -> RemoveContentResponse:
        """
        Removes the content that matches the given request.

        Args:
          request (RemoveContentRequest): The request to send.
        
        Returns:
          RemoveContentResponse: The response.
        """
        stub = NLPServerStub(self.channel)
        return stub.RemoveContent(request)
    
    def update_project(self, request: UpdateProjectRequest) -> UpdateProjectResponse:
        """
        Updates the project that matches the given request.

        Args:
          request (UpdateContentRequest): The request to send.
        
        Returns:
          UpdateProjectResponse: The response.
        """
        stub = NLPServerStub(self.channel)
        return stub.UpdateProject(request)
    
    def remove_project(self, request: RemoveProjectRequest) -> RemoveProjectResponse:
        """
        Removes the project that matches the given request.

        Args:
          request (RemoveProjectRequest): The request to send.
        
        Returns:
          RemoveProjectResponse: The response.
        """
        stub = NLPServerStub(self.channel)
        return stub.RemoveProject(request)
    
    def add_projects(self, request: AddProjectRequest) -> AddProjectResponse:
        """
        Adds a project with the given request.

        Args:
          request (AddProjectRequest): The request to send.
        
        Returns:
          AddProjectReponse: The response.
        """
        stub = NLPServerStub(self.channel)
        return stub.AddProject(request)